@@ -12,9 +12,9 @@
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General
 # Public License for more details.
 # 
-# You should have received a copy of the GNU General Public License along
-# with this program; if not, write to the Free Software Foundation, Inc.,
-# 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
+# You should have received a copy of the GNU General Public License along with
+# this program; if not, write to the Free Software Foundation, Inc., 
+# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA
 
 
 """Distributed piuparts processing, master program
@@ -34,7 +34,7 @@ import tempfile
 import piupartslib
 
 
-CONFIG_FILE = "piuparts-master.conf"
+CONFIG_FILE = "/etc/piuparts/piuparts.conf"
 
 
 def setup_logging(log_level, log_file_name):
@@ -178,86 +178,21 @@ class Master(Protocol):
         self._db.make_package_untestable(args[0], args[1], log)
         self._short_response("ok")
 
-    def count_packages_in_states(self, states):
-        count = 0
-        for state in states:
-            count += len(self._db.get_packages_in_state(state))
-        return count
-
-    def rename_if_newer_else_delete(self, orig, new):
-        ok = True
-        if os.path.exists(orig):
-            st_orig = os.stat(orig)
-            st_new = os.stat(new)
-            ok = st_orig.st_mtime < st_new.st_mtime
-        if ok:
-            os.rename(new, orig)
-        else:
-            os.remove(new)
-
-    def write_counts_summary(self):
-        fd, name = tempfile.mkstemp(prefix="counts.txt.", dir=".")
-        os.close(fd)
-        os.chmod(name, 0644)
-
-        failed = self.count_packages_in_states(self._failed_states)
-        passed = self.count_packages_in_states(self._passed_states)
-
-        f = file(name, "w")
-        f.write("Fail: %d\n" % failed)
-        f.write("Pass: %d\n" % passed)
-        f.close()
-        self.rename_if_newer_else_delete("counts.txt", name)
-
-    def find_log(self, package):
-        n = self._db._logdb._log_name(package["Package"], package["Version"])
-        for dirname in self._db._all:
-            nn = os.path.join(dirname, n)
-            if os.path.exists(nn):
-                return nn
-        return None
-
-    def write_packages_summary(self):
-        fd, name = tempfile.mkstemp(prefix="packages.txt.", dir=".")
-        os.close(fd)
-        os.chmod(name, 0644)
-
-        f = file(name, "w")
-        for pkgname in self._db._packages:
-            state = self._db.state_by_name(pkgname)
-            logname = self.find_log(self._db._packages[pkgname]) or ""
-            f.write("%s %s %s\n" % (pkgname, state, logname))
-        f.close()
-
-        self.rename_if_newer_else_delete("packages.txt", name)
-
-    def write_summaries(self):
-        self.write_counts_summary()
-        self.write_packages_summary()
-
-
 def main():
-    # For supporting multiple architectures and suites, we take a command-line
-    # argument referring to a section in the master configuration file.  For
-    # backwards compatibility, if no argument is given, the "master" section is
-    # assumed.
+    # piuparts-master is always called by the slave with a section as argument
     if len(sys.argv) == 2:
         section = sys.argv[1]
         config = Config(section=section)
-    else:
-        section = None
-        config = Config()
-    config.read(CONFIG_FILE)
+        config.read(CONFIG_FILE)
     
-    setup_logging(logging.DEBUG, config["log-file"])
+        setup_logging(logging.DEBUG, config["log-file"])
     
-    logging.info("Fetching %s" % config["packages-url"])
-    packages_file = piupartslib.open_packages_url(config["packages-url"])
-    m = Master(sys.stdin, sys.stdout, packages_file, section=section)
-    packages_file.close()
-    while m.do_transaction():
-        pass
-    m.write_summaries()
+        logging.info("Fetching %s" % config["packages-url"])
+        packages_file = piupartslib.open_packages_url(config["packages-url"])
+        m = Master(sys.stdin, sys.stdout, packages_file, section=section)
+        packages_file.close()
+        while m.do_transaction():
+            pass
 
 
 if __name__ == "__main__":
